CFM.plotCFGraphComparison: CFM: Compare two Graphs

View source: R/careFlowMiner.wrapper.R

CFM.plotCFGraphComparisonR Documentation

CFM: Compare two Graphs

Description

Compare two graphs, stratyfing for a given covariate

Usage

CFM.plotCFGraphComparison(
  objCFM,
  stratifyFor,
  stratificationValues,
  depth = 4,
  fisher.threshold = 0.1,
  arr.States.color = c()
)

Arguments

objCFM

the careFlowMiner obj.

stratifyFor

the dicotomic attribute you want to use to stratify. It should be the same for all the record of a specific patients (it is a baseline attribute).

depth

max depth level (default = 4)

fisher.threshold

bla bla bla

arr.States.color

an array contaning the association between nodes and color


robertogattabs/pMiner.v045b documentation built on Aug. 2, 2022, 1:53 p.m.