View source: R/EfirstOrderMarkovModel.R
| EfirstOrderMarkovModel | R Documentation |
This is an implementation of the First Order Markov Model (EfirstOrderMarkovModel) for Process Mining issues. This class provides a minimal set of methods to handle with the FOMM model:
EfirstOrderMarkovModel( ) is the costructor
loadDataset( ) loads data taken from a dataLoader::getData() method, into a FOMM object
trainModel( ) train a model using the previously loaded dataset
replay( ) re-play a given event log on the internal FOMM model
play( ) play the internal FOMM model a desired number of times, in order to simulate new event-logs. This methods can also, if desired, simulate event-logs which does not complies with the internal FOMM model.
plot( ) plot the internal model
getModel( ) return the trained internal FOMM model
getInstanceClass( ) return the instance class Name and description (version, etc.)
findReacheableNodes( ) and return the array containing the reacheable states, starting from the passed one.
In order to better undestand the use of such methods, please visit: www.pminer.info
The consturctor admit the following parameters: parameters.list a list containing possible parameters to tune the model.
EfirstOrderMarkovModel(parameters.list = list())
parameters.list |
a list containing the parameters. The possible ones are: 'considerAutoLoop' and 'threshold'. 'considerAutoLoop' is a boolean which indicates if the autoloops have to be admitted, while 'threshold' is the minimum value that a probability should have to do not be set to zero, in the transition matrix. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.