| logInspector | R Documentation |
This class aims at inspecting an event-log for descriptive analysis purposes. The public methods are:
logInspector( ) is the constructor of the class
loadDataset( ) loads data taken from a dataLoader::getData() method, into a logInspector() object
getEventStats() computes and returns event-related stats, such as absolute and relative events frequency
getProcessStats() computes and returns process-related stats, such as absolute and relative processes frequency
In order to better undestand the use of such methods, please visit: www.pminer.info
Parameter for logInspector::plotEventStats() and logInspector::plotProcessStats() methods is:
num the number of most frequent events/processes to plot
logInspector()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.