View source: R/careFlowMiner.wrapper.R
| CFM.plotCFGraph | R Documentation |
Plot the graph containing the stories
CFM.plotCFGraph( objCFM, depth = 2, starting.ID = "root", kindOfGraph = "twopi", GraphFontsize = "9", withPercentages = TRUE, relative.percentages = FALSE, proportionalPenwidth = TRUE, default.arcColor = "Black", arr.States.color = c(), predictive.model = FALSE, predictive.model.outcome = "", predictive.model.skipNodeLabel = c(), preserve.topology = FALSE, set.to.gray = FALSE, set.to.gray.color = "WhiteSmoke" )
objCFM |
the |
depth |
the depht of the final graph, with the respect of the initial node |
starting.ID |
the starting node (the default is the |
kindOfGraph |
the shape of the graph. Can be |
GraphFontsize |
set to 9 by default |
withPercentages |
default = |
relative.percentages |
default = |
proportionalPenwidth |
default = |
default.arcColor |
default = |
arr.States.color |
an array by which you can specify for some nodes (key) the associated color(value). E.g. c("Home"="Black","Hospital"="Red") |
predictive.model |
default = |
predictive.model.outcome |
the array of nodes which represent the goals in predicting the evolution. This makes sense if |
predictive.model.skipNodeLabel |
Shit, I forgot the meaning of this parameter |
preserve.topology |
default = |
set.to.gray |
default = |
set.to.gray.color |
default = |
## Not run:
# instantiate a dataLoader object
library(pMineR)
tmp.objDL <- dataLoader()
invisible(tmp.objDL$load.data.frame( mydata = data.frame(myInputCSVData) , IDName = "PatientID",EVENTName = "clinicalEvent",
dateColumnName = "STRT_DT", format.column.date = "%Y-%m-%d %H:%M:%S" ))
DLS <- tmp.objDL$getData()
a <- careFlowMiner()
a$loadDataset(DLS = DLS , dateToColumnName = "END_DT",dateToFormat="%Y-%m-%d %H:%M:%S")
b <- CFM.plotCFGraph(objCFM = a, depth = 4,kindOfGraph = "neato",default.arcColor = "Red",
arr.States.color=c("Deces"="Red","intensive care"="Orange","Recovered"="YellowGreen"),
predictive.model = TRUE, predictive.model.outcome = "Deces",
predictive.model.skipNodeLabel = c("Deces","Recovered"), preserve.topology = TRUE )
grViz(b$script)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.