View source: R/careFlowMiner.wrapper.R
| CFM.plotCFGraphComparison | R Documentation |
Compare two graphs, stratyfing for a given covariate
CFM.plotCFGraphComparison( objCFM, stratifyFor, stratificationValues, depth = 4, fisher.threshold = 0.1, arr.States.color = c() )
objCFM |
the |
stratifyFor |
the dicotomic attribute you want to use to stratify. It should be the same for all the record of a specific patients (it is a baseline attribute). |
depth |
max depth level (default = 4) |
fisher.threshold |
bla bla bla |
arr.States.color |
an array contaning the association between nodes and color |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.